@@ -41,8 +41,6 @@ class AppSetup(Controller):
         self.app.log.info(f'creating plugin {plugin_name} using language {language}')
         try:
             templates = self.app.config.get('kluff', 'templates')
-            print(templates)
-            sys.exit()
             backend_template = os.path.join(templates, language)
             frontend_template = os.path.join(templates, 'react')
             apps_path = self.app.config.get('kluff', 'apps')
